@@ -1,5 +1,3 @@
-""" visualizes entities on a canvas """
-
 import datetime
 from typing import List, Optional
 from casymda.blocks.entity import Entity
@@ -18,6 +16,8 @@ class EntityAnimation:
 
 
 class EntityVisualizer:
+    """ visualizes entities on a canvas when notified """
+
     def __init__(
         self,
         canvas: ScaledCanvas,
