@@ -6,10 +6,13 @@ from multiprocessing import Manager, Process, Value
 from typing import Optional
 
 from casymda.environments.realtime_environment import SyncedFloat
+from casymda.visualization.canvas import web_canvas
+
+from .flatbuffers import flatbuffer_serializer
 
 
 class RunnableSimulation:
-    """ abstract base class for simulations to be run via a SimController """
+    """abstract base class for simulations to be run via a SimController"""
 
     width: int
     height: int
@@ -22,7 +25,7 @@ class RunnableSimulation:
 
 
 class SimController:
-    """ wraps RunnableSimulation to be controlled by a sim-server """
+    """wraps RunnableSimulation to be controlled by a sim-server"""
 
     def __init__(self, simulation: RunnableSimulation) -> None:
 
@@ -67,7 +70,35 @@ class SimController:
         return "reset"
 
     def get_state_dumps(self):
-        return json.dumps(self.shared_state.copy())
+        state = self._get_state_dumps()
+        return json.dumps(state)
+
+    def get_partial_state_dumps(self):
+        state = self._get_partial_state_dumps()
+        return json.dumps(state)
+
+    def get_state_dumps_fb(self):
+        state = self._get_state_dumps()
+        return flatbuffer_serializer.serialize(state)
+
+    def get_partial_state_dumps_fb(self):
+        state = self._get_partial_state_dumps()
+        return flatbuffer_serializer.serialize(state)
+
+    def _get_state_dumps(self):
+        self.shared_state[web_canvas.UPDATED_KEY] = set()  # reset
+        state = self.shared_state.copy()
+        del state[web_canvas.UPDATED_KEY]
+        return state
+
+    def _get_partial_state_dumps(self):
+        updated_set = set(self.shared_state[web_canvas.UPDATED_KEY])
+        state = self.shared_state.copy()
+        self.shared_state[web_canvas.UPDATED_KEY] = set()  # reset
+        del state[web_canvas.UPDATED_KEY]
+        for not_updated in state.keys() - updated_set:
+            del state[not_updated]
+        return state
 
     def set_rt_factor(self, value: float):
         return "set factor to " + str(self.factor.set_value(value))
